"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.APIGatewayHelper = void 0;
const APIGateway = require("@aws-sdk/client-api-gateway");
const typescript_helper_functions_1 = require("typescript-helper-functions");
class APIGatewayHelper extends typescript_helper_functions_1.BaseClass {
    Repository;
    constructor(logger, repository, options) {
        super(logger);
        options = this.ObjectOperations.IsNullOrEmpty(options)
            ? { region: 'us-east-1' }
            :
                options;
        this.Repository = repository || new APIGateway.APIGateway(options);
    }
    async CreateApiKeyAsync(name, description, value) {
        const action = `${APIGatewayHelper.name}.${this.CreateApiKeyAsync.name}`;
        this.LogHelper.LogInputs(action, { name, description, value });
        if (this.ObjectOperations.IsNullOrWhitespace(name)) {
            throw new Error(`[${action}]-Must supply name`);
        }
        if (this.ObjectOperations.IsNullOrWhitespace(description)) {
            throw new Error(`[${action}]-Must supply description`);
        }
        const params = {
            description,
            name,
        };
        if (this.ObjectOperations.IsNullOrWhitespace(value)) {
            params.generateDistinctId = true;
        }
        else {
            params.value = value;
        }
        this.LogHelper.LogRequest(action, params);
        const response = await this.Repository.createApiKey(params);
        this.LogHelper.LogResponse(action, response);
        return response;
    }
    async CreateUsagePlanAsync(name, description, apiStages, quota, throttle) {
        const action = `${APIGatewayHelper.name}.${this.CreateUsagePlanAsync.name}`;
        this.LogHelper.LogInputs(action, {
            name,
            description,
            apiStages,
            quota,
            throttle,
        });
        if (this.ObjectOperations.IsNullOrWhitespace(name)) {
            throw new Error(`[${action}]-Must supply name`);
        }
        if (this.ObjectOperations.IsNullOrWhitespace(description)) {
            throw new Error(`[${action}]-Must supply description`);
        }
        if (!apiStages || apiStages.length === 0) {
            throw new Error(`[${action}]-Must supply at least one apiStage`);
        }
        const params = {
            apiStages,
            description,
            name,
            quota,
            throttle,
        };
        this.LogHelper.LogRequest(action, params);
        const response = await this.Repository.createUsagePlan(params);
        this.LogHelper.LogResponse(action, response);
        return response;
    }
    async CreateUsagePlanKeyAsync(keyId, keyType, usagePlanId) {
        const action = `${APIGatewayHelper.name}.${this.CreateUsagePlanKeyAsync.name}`;
        this.LogHelper.LogInputs(action, { keyId, keyType, usagePlanId });
        if (this.ObjectOperations.IsNullOrWhitespace(keyId)) {
            throw new Error(`[${action}]-Must supply keyId`);
        }
        if (this.ObjectOperations.IsNullOrWhitespace(keyType)) {
            throw new Error(`[${action}]-Must supply keyType`);
        }
        if (this.ObjectOperations.IsNullOrWhitespace(usagePlanId)) {
            throw new Error(`[${action}]-Must supply usagePlanId`);
        }
        const params = {
            keyId,
            keyType,
            usagePlanId,
        };
        this.LogHelper.LogRequest(action, params);
        const response = await this.Repository.createUsagePlanKey(params);
        this.LogHelper.LogResponse(action, response);
        return response;
    }
    async DeleteApiKeyAsync(apiKey) {
        const action = `${APIGatewayHelper.name}.${this.DeleteApiKeyAsync.name}`;
        this.LogHelper.LogInputs(action, { apiKey });
        if (this.ObjectOperations.IsNullOrWhitespace(apiKey)) {
            throw new Error(`[${action}]-Must supply apiKey`);
        }
        const params = {
            apiKey,
        };
        this.LogHelper.LogRequest(action, params);
        const response = await this.Repository.deleteApiKey(params);
        this.LogHelper.LogResponse(action, response);
        return response;
    }
    async DeleteUsagePlanAsync(usagePlanId) {
        const action = `${APIGatewayHelper.name}.${this.DeleteUsagePlanAsync.name}`;
        this.LogHelper.LogInputs(action, { usagePlanId });
        if (this.ObjectOperations.IsNullOrWhitespace(usagePlanId)) {
            throw new Error(`[${action}]-Must supply usagePlanId`);
        }
        const params = {
            usagePlanId,
        };
        this.LogHelper.LogRequest(action, params);
        const response = await this.Repository.deleteUsagePlan(params);
        this.LogHelper.LogResponse(action, response);
        return response;
    }
    async DeleteUsagePlanKeyAsync(keyId, usagePlanId) {
        const action = `${APIGatewayHelper.name}.${this.DeleteUsagePlanKeyAsync.name}`;
        this.LogHelper.LogInputs(action, { keyId, usagePlanId });
        if (this.ObjectOperations.IsNullOrWhitespace(keyId)) {
            throw new Error(`[${action}]-Must supply keyId`);
        }
        if (this.ObjectOperations.IsNullOrWhitespace(usagePlanId)) {
            throw new Error(`[${action}]-Must supply usagePlanId`);
        }
        const params = {
            keyId,
            usagePlanId,
        };
        this.LogHelper.LogRequest(action, params);
        const response = await this.Repository.deleteUsagePlanKey(params);
        this.LogHelper.LogResponse(action, response);
        return response;
    }
    async GetApiKeyAsync(apiKey) {
        const action = `${APIGatewayHelper.name}.${this.GetApiKeyAsync.name}`;
        this.LogHelper.LogInputs(action, { apiKey });
        if (this.ObjectOperations.IsNullOrWhitespace(apiKey)) {
            throw new Error(`[${action}]-Must supply apiKey`);
        }
        const params = {
            apiKey,
        };
        this.LogHelper.LogRequest(action, params);
        const response = await this.Repository.getApiKey(params);
        this.LogHelper.LogResponse(action, response);
        return response;
    }
}
exports.APIGatewayHelper = APIGatewayHelper;
//# sourceMappingURL=helper.js.map